/*
 * Home Health Grouper
 * Developer for the Center for Medicare and Medicaid Services CMS
 * by 3M Health Information Systems  for CMS Home Health.
 *
 * All code is provided as is.
 */
package com.mmm.cms.homehealth.beans;

import java.io.Serializable;

/**
 * This is the base bean for providing valid values for text fields
 *
 * @author 3M Health Information Systems  for CMS Home Health
 *
 */
public class BaseHomeHealthBean implements Serializable {

    protected String fieldName;
    protected String title;
    protected String[] validValues;
    protected String[] valueLabels;
    protected int startPosition;
    protected int length;

    public BaseHomeHealthBean() {
    }

    public BaseHomeHealthBean(String fieldName, String[] values) {
        this.fieldName = fieldName;
        this.validValues = values;
    }
    
    public BaseHomeHealthBean(String fieldName, String title, String[] values, String[] labels) {
        this.fieldName = fieldName;
        this.title = title;
        this.validValues = values;
        this.valueLabels = labels;
    }

    public String getFieldName() {
        return fieldName;
    }

    public int getLength() {
        return length;
    }

    public int getStartPosition() {
        return startPosition;
    }

    public String getTitle() {
        return this.title;
    }

    /**
     * Get the value of valueLabels
     *
     * @return the value of valueLabels
     */
    public String[] getValueLabels() {
        return this.valueLabels == null ? this.validValues : this.valueLabels;
    }
    
    /**
     * Get the value of valueLabels at specified index
     *
     * @param index
     * @return the value of valueLabels at specified index
     */
    public String getValueLabel(int idx) {
        return this.valueLabels == null ? this.validValues[idx] : this.valueLabels[idx];
    }

    public String[] getValidValues() {
        return this.validValues.clone();
    }

    public String getValidValue(int index) {
        return this.validValues[index];
    }

    /**
     * Utility method to check the actualValue against the validValues.
     *
     * @param actualValue can be null
     * @return true if the actualValue is contained within the valueValues
     */
    public boolean isValidValue(String actualValue) {
		boolean valid = false;
        if (actualValue != null && !actualValue.isEmpty()) {
            for (int idx = validValues.length; idx > 0;) {
                if (actualValue.equals(validValues[--idx])) {
                    valid = true;
					break;
                }
            }
        }
        return valid;
    }

    public void setFieldName(String fieldName) {
        this.fieldName = fieldName;
    }

    public void setLength(int length) {
        this.length = length;
    }

    public void setStartPosition(int startPosition) {
        this.startPosition = startPosition;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public void setValidValues(String[] lines) {
        this.validValues = lines;
    }

    public void setValidValues(int index, String line) {
        if (this.validValues == null) {
            this.validValues = new String[1];
        } else if (index == this.validValues.length) {
            String tmpValues[] = this.validValues;
            this.validValues = new String[tmpValues.length + 1];
            System.arraycopy(tmpValues, 0, this.validValues, 0, tmpValues.length);
        }

        this.validValues[index] = line;
    }

    /**
     * Set the value of valueLabels
     *
     * @param valueLabels new value of valueLabels
     */
    public void setValueLabels(String[] valueLabels) {
        this.valueLabels = valueLabels;
    }

    /**
     * Set the value of valueLabels at specified index.
     *
     * @param index
     * @param newValueLabels new value of valueLabels at specified index
     */
    public void setValueLabels(int index, String newValueLabels) {
        if (this.valueLabels == null) {
            this.valueLabels = new String[1];
        } else if (index == this.valueLabels.length) {
            String tmpValues[] = this.valueLabels;
            this.valueLabels = new String[tmpValues.length + 1];
            System.arraycopy(tmpValues, 0, this.valueLabels, 0, tmpValues.length);
        }
        this.valueLabels[index] = newValueLabels;
    }
}
